<?php
/*
Plugin Name: PostRank Feed
Plugin URI: http://www.icoro.com/
Description: PostRankのFeedを表示します。表示したい場所に<code>&lt;?php postrank_feed(); ?&gt;</code>と入力して下さい。
Author: icoro
Version: 1.0
Author URI: http://www.icoro.com/
*/

if( $_SERVER['SCRIPT_FILENAME'] == __FILE__ ) die();

/******************************************************************************
 * 定数の設定 (主にディレクトリのパスとか)
 *****************************************************************************/
if ( ! defined( 'POSTRANK_FEED_PLUGIN_URL' ) )
	define( 'POSTRANK_FEED_PLUGIN_URL', WP_PLUGIN_URL . '/' . plugin_basename( dirname( __FILE__ ) ) );


/******************************************************************************
 * 本体
 *****************************************************************************/
class PostRankFeed {

	private $config;

	function __construct() {

		$this->config = array(
			'apikey'		=> $_SERVER['HTTP_HOST'],						// APIKey
			'site_url'		=> get_bloginfo('url'),							// feed URL
			'hash'			=> '',											// Feed Hash
			'interval'		=> 60*60*1,										// cacheの有効時間(秒単位)
			'cached_time'	=> get_option('postrankfeed_cached_time', 0),
			'num_posts'		=> 10
		);

		if( ! $hash = get_option( 'postrankfeed_hash' ) ) {
			$hash = $this->get_hash();
			update_option( 'postrankfeed_hash', $hash );
		}
		$this->config['hash'] = $hash;

	}

	function get_hash() {
		$url = 'http://api.postrank.com/v2/feed/info?id=' . $this->config['site_url'] . '&';
		$url .= 'appkey=' . $this->config['apikey'] . '&format=json';

		if( ! $jsondata = @file_get_contents( $url ) ) {
//			echo "<!-- PostRank Feed: no feed -->\n";
			return false;
		}
		$json = json_decode($jsondata);
		return $json->id;
	}

	public function postrank_feed_view() {
		$this->get_json_or_cache();
	}

	function get_json_or_cache() {
	
		$update_time = $this->config['cached_time'] + $this->config['interval'];

		if( time() < $update_time ) {
			$json = $this->get_json_cache();
//			echo '<p>cache</p>';
		} else {
			$json = $this->get_json();
//			echo '<p>not cache</p>';
		}

		if ( $json ) {
			$html = $this->generate_html( $json );
			echo $html;
		}
	}

	function get_json_cache() {
		$json = get_option( 'postrankfeed_json' );
		return $json;
	}

	function get_json() {
//		$url = 'http://api.postrank.com/v2/feed/' . $this->config['hash'] . '/topposts?';
//		$url = 'http://api.postrank.com/v2/feed/' . $this->config['hash'] . '/topposts?' . 'level=good&';
//		$url = 'http://api.postrank.com/v2/feed/' . $this->config['hash'] . '?';
		$url = 'http://api.postrank.com/v2/feed/' . $this->config['hash'] . '?' . 'level=good&';
		$url .= 'appkey=' . $this->config['apikey'] . '&format=json&num=' . $this->config['num_posts'];

		if( ! $jsondata = @file_get_contents( $url ) ) {
			echo "<!-- PostRank Feed: no feed -->\n";
			return false;
		}

		$json = json_decode($jsondata);

		if( count( $json->items ) < 1 ) {
			return false;
		}

		update_option( 'postrankfeed_cached_time', time() );
		update_option( 'postrankfeed_json', $json );

		return $json;
	}

	function generate_html( $json ) {
		$html = '<dl class="list link_list postrank">';
		$html .= '<dt>最近の人気の高い記事</dt>';
		foreach( $json->items as $item ) {
			$html .= '<dd>';
			$html .= '<a href="' . $item->original_link . '">' . $item->title . '</a>';
			$html .= ' <span style="background-color:' . $item->postrank_color . ';">' . $item->postrank . '&nbsp;pts</span>';
			$html .= '</dd>';
		}
		$html .= '<dd class="powerdby">Powerd by <a href="http://www.postrank.com/">PostRank</a></dd>';
		$html .= '</dl>';

		return $html;
	}

	function uninstall() {
		delete_option( 'postrankfeed_cached_time' );
		delete_option( 'postrankfeed_json' );
		delete_option( 'postrankfeed_hash' );
	}

}


/******************************************************************************
 * 関数の設定
 *****************************************************************************/
if( ! function_exists( 'postrank_feed' ) ) {
	function postrank_feed() {
		global $postRankFeed;
		$postRankFeed->postrank_feed_view();
	}
}

function add_postrankfeed_stylesheet(){
	?>
<link rel="stylesheet" href="<?php echo POSTRANK_FEED_PLUGIN_URL; ?>/postrank-feed.css" type="text/css" media="screen" />
	<?php
}


/******************************************************************************
 * プログラムの実行
 *****************************************************************************/
$postRankFeed = new PostRankFeed();
$plugin_basename = plugin_basename(__FILE__);

add_action( 'wp_head', 'add_postrankfeed_stylesheet' );
add_action( 'deactivate_' . $plugin_basename, array( & $postRankFeed, 'uninstall' ) );

?>